@@ -209,9 +209,15 @@ sub dump_bootstrap {
     my @inc  = map $_->nonempty_libs, @artifacts;
     my @path = map $_->nonempty_paths, @artifacts;
 
+    my(%execs);
+    for my $artifact (@artifacts) {
+        my %bins = $artifact->executables;
+        $execs{$artifact->package} = \%bins if %bins;
+    }
+
     my %modules;
     for my $artifact (@artifacts) {
-        %modules = (%modules, %{$artifact->module_files});
+        %modules = (%modules, $artifact->module_files);
     }
 
     my $cpanfile = $self->try_cpanfile
@@ -229,6 +235,7 @@ package $package;
 our %environment = (
 inc     => @{[ quote \@inc ]},
 path    => @{[ quote \@path ]},
+execs   => @{[ quote \%execs ]},
 base    => @{[ quote(Path::Tiny->cwd) ]},
 modules => @{[ quote \%modules ]},
 prereqs => @{[ quote $prereqs ]},
@@ -274,7 +281,9 @@ sub cmd_list {
     my($self, @args) = @_;
 
     if (my $module = shift @args) {
-        $self->show_module($module);
+        my $artifact = $self->artifact_for($module);
+        printf "%s (%s) in %s\n", $artifact->package, $artifact->version || '0', $artifact->path
+          if $artifact;
         return;
     }
 
@@ -286,14 +295,15 @@ sub cmd_list {
     }
 }
 
-sub show_module {
+sub artifact_for {
     my($self, $module) = @_;
 
+    my $found;
     eval {
         $self->resolve(sub {
             my $artifact = shift;
             if ($module eq $artifact->package) {
-                printf "%s (%s) in %s\n", $artifact->package, $artifact->version || '0', $artifact->path;
+                $found = $artifact;
                 die "__FOUND__\n";
             }
         });
@@ -301,6 +311,7 @@ sub show_module {
     };
 
     die $@ if $@ && $@ ne "__FOUND__\n";
+    return $found;
 }
 
 sub cmd_tree {
@@ -417,6 +428,29 @@ sub build_index {
     $index;
 }
 
+sub cmd_binstubs {
+    my($self, @package) = @_;
+
+    die "Usage: carmel binstubs Module [...]\n" unless @package;
+
+    for my $package (@package) {
+        my $artifact = $self->artifact_for($package);
+        my %execs = $artifact->executables;
+        for my $bin (keys %execs) {
+            my $path = Path::Tiny->new("bin/$bin");
+            $path->parent->mkpath;
+            $path->spew(<<EOF);
+#!/usr/bin/env perl
+# This file was generated by Carmel
+use Carmel::Setup;
+my \$res = do Carmel::Setup->bin_path('@{[ $artifact->package ]}', '$bin');
+if (!defined \$res and my \$err = \$@ || \$!) { die \$err }
+EOF
+            $path->chmod(0755);
+        }
+    }
+}
+
 sub try_snapshot {
     my $self = shift;
 
@@ -525,7 +559,8 @@ sub resolve {
     my($self, $cb, $missing_cb) = @_;
     $missing_cb ||= sub {
         my($module, $want_version, $depth) = @_;
-        die "Can't find an artifact for $module => $want_version\nYou need to run `carmel install` first to get the modules installed and artifacts built.\n";
+        die "Can't find an artifact for $module => $want_version\n" .
+            "You need to run `carmel install` first to get the modules installed and artifacts built.\n";
     };
     $self->resolve_recursive($self->requirements, $self->requirements->clone, {}, $cb, $missing_cb, 0);
 }
